@@ -10,8 +10,6 @@ from suite_py.__version__ import __version__
 from suite_py.commands.ask_review import AskReview
 from suite_py.commands.check import Check
 from suite_py.commands.create_branch import CreateBranch
-from suite_py.commands.create_qa import CreateQA
-from suite_py.commands.delete_qa import DeleteQA
 from suite_py.commands.release import Release
 from suite_py.commands.deploy import Deploy
 from suite_py.commands.generator import Generator
@@ -68,7 +66,17 @@ def main(ctx, project, timeout, verbose):
         print(f"the folder {project} is not in {config.user['projects_home']}")
         sys.exit(-1)
 
-    if not config.user.get("skip_confirmation", False) and not prompt_utils.ask_confirm(
+    skip_confirmation = False
+    if type(config.user.get("skip_confirmation")).__name__ == "bool":
+        skip_confirmation = config.user.get("skip_confirmation")
+    elif type(
+        config.user.get("skip_confirmation")
+    ).__name__ == "list" and ctx.invoked_subcommand in config.user.get(
+        "skip_confirmation"
+    ):
+        skip_confirmation = True
+
+    if not skip_confirmation and not prompt_utils.ask_confirm(
         f"Do you want to continue on project {os.path.basename(project)}?"
     ):
         sys.exit()
@@ -131,18 +139,6 @@ def cli_ask_review(obj):
     AskReview(obj["project"], obj["config"], obj["tokens"]).run()
 
 
-@main.command("create-qa", help="Create QA env (integration with qainit)")
-@click.pass_obj
-def cli_create_qa(obj):
-    CreateQA(obj["project"], obj["config"], obj["tokens"]).run()
-
-
-@main.command("delete-qa", help="Delete QA env (integration with qainit)")
-@click.pass_obj
-def cli_delete_qa(obj):
-    DeleteQA(obj["project"], obj["config"], obj["tokens"]).run()
-
-
 @main.command(
     "merge-pr", help="Merge the selected branch to master if all checks are OK"
 )
@@ -259,35 +255,50 @@ def cli_qa_list(obj, user, status, card):
 @click.argument("microservices", nargs=-1, required=True)
 @click.pass_obj
 def cli_qa_create(obj, microservices):
-    QA("create", obj["project"], obj["config"], obj["tokens"], microservices).run()
+    QA(
+        "create",
+        obj["project"],
+        obj["config"],
+        obj["tokens"],
+        {"services": microservices},
+    ).run()
 
 
 @qa.command("update", help="Update QA env")
-@click.argument("arguments", nargs=-1, required=True)
+@click.argument("qa_hash", required=True)
+@click.argument("microservices", nargs=-1, required=True)
 @click.pass_obj
-def cli_qa_update(obj, arguments):
-    QA("update", obj["project"], obj["config"], obj["tokens"], arguments).run()
+def cli_qa_update(obj, qa_hash, microservices):
+    QA(
+        "update",
+        obj["project"],
+        obj["config"],
+        obj["tokens"],
+        {"hash": qa_hash, "services": microservices},
+    ).run()
 
 
 @qa.command("delete", help="Delete QA env")
 @click.argument("qa_hash", required=True)
 @click.pass_obj
 def cli_qa_delete(obj, qa_hash):
-    QA("delete", obj["project"], obj["config"], obj["tokens"], qa_hash).run()
+    QA("delete", obj["project"], obj["config"], obj["tokens"], {"hash": qa_hash}).run()
 
 
 @qa.command("freeze", help="Freeze QA env")
 @click.argument("qa_hash", required=True)
 @click.pass_obj
 def cli_qa_freeze(obj, qa_hash):
-    QA("freeze", obj["project"], obj["config"], obj["tokens"], qa_hash).run()
+    QA("freeze", obj["project"], obj["config"], obj["tokens"], {"hash": qa_hash}).run()
 
 
 @qa.command("unfreeze", help="Unfreeze QA env")
 @click.argument("qa_hash", required=True)
 @click.pass_obj
 def cli_qa_unfreeze(obj, qa_hash):
-    QA("unfreeze", obj["project"], obj["config"], obj["tokens"], qa_hash).run()
+    QA(
+        "unfreeze", obj["project"], obj["config"], obj["tokens"], {"hash": qa_hash}
+    ).run()
 
 
 @qa.command("check", help="Check QA conf")
@@ -301,7 +312,7 @@ def cli_qa_check(obj):
 @click.option("--json", is_flag=True, default=False, help="Get response as JSON")
 @click.pass_obj
 def cli_qa_describe(obj, qa_hash, json):
-    flags = {"qa_hash": qa_hash, "json": json}
+    flags = {"hash": qa_hash, "json": json}
     QA("describe", obj["project"], obj["config"], obj["tokens"], flags).run()
 
 
