@@ -53,16 +53,38 @@ class QA:
 
         self._qainit.user_info()
 
+    def _create_instance_table(self):
+        instance_table = Table()
+        instance_table.add_column("Name", style="purple")
+        instance_table.add_column("Hash", style="green")
+        instance_table.add_column("Card", style="white")
+        instance_table.add_column("Created by", style="white")
+        instance_table.add_column("Updated by", style="white")
+        instance_table.add_column("Deleted by", style="white")
+        instance_table.add_column("Status", style="white")
+
+        return instance_table
+
+    def _insert_instance_record(self, table, qa):
+        table.add_row(
+            qa["name"],
+            qa["hash"],
+            qa["card"],
+            qa.get("created", {}).get("github_username", "/")
+            if qa["created"] is not None
+            else "/",
+            qa.get("updated", {}).get("github_username", "/")
+            if qa["updated"] is not None
+            else "/",
+            qa.get("deleted", {}).get("github_username", "/")
+            if qa["deleted"] is not None
+            else "/",
+            qa["status"],
+        )
+
     def _list(self):
         # init empty table with column (useful for reset)
-        empty_table = Table()
-        empty_table.add_column("Name", style="purple")
-        empty_table.add_column("Hash", style="green")
-        empty_table.add_column("Card", style="white")
-        empty_table.add_column("Created by", style="white")
-        empty_table.add_column("Updated by", style="white")
-        empty_table.add_column("Deleted by", style="white")
-        empty_table.add_column("Status", style="white")
+        empty_table = self._create_instance_table()
         table = copy.deepcopy(empty_table)
         console = Console()
 
@@ -77,21 +99,8 @@ class QA:
             response = r.json()
             qa_list = response["list"]
             for qa in qa_list:
-                table.add_row(
-                    qa["name"],
-                    qa["hash"],
-                    qa["card"],
-                    qa.get("created", {}).get("github_username", "/")
-                    if qa["created"] is not None
-                    else "/",
-                    qa.get("updated", {}).get("github_username", "/")
-                    if qa["updated"] is not None
-                    else "/",
-                    qa.get("deleted", {}).get("github_username", "/")
-                    if qa["deleted"] is not None
-                    else "/",
-                    qa["status"],
-                )
+                self._insert_instance_record(table, qa)
+
             console.print(table)
 
             # break conditions
@@ -114,12 +123,19 @@ class QA:
         if jsonify:
             print(json.dumps(r, sort_keys=True, indent=2))
         else:
+            # RESOURCES TABLE
             table = Table()
             table.add_column("Microservice", style="purple", no_wrap=True)
             table.add_column("Drone build")
             table.add_column("Branch", style="white")
             table.add_column("Status", style="white")
 
+            # INSTANCE TABLE
+            instance_table = self._create_instance_table()
+
+            self._insert_instance_record(instance_table, r["list"])
+
+            # DNS TABLE
             dns_table = Table()
             dns_table.add_column("Name", style="purple", no_wrap=True)
             dns_table.add_column("Record", style="green")
@@ -153,6 +169,7 @@ class QA:
                             resource["status"],
                         )
 
+                console.print(instance_table)
                 console.print(dns_table)
                 console.print(table)
             except TypeError:
